@@ -282,6 +282,7 @@ our ($NAME, $SHORT_DESC, $SYNOPSIS, $DESCRIPTION, @options);
 #  get the synopsis, etc, from the calling script.
 #---------------------------------------------------------------------
 sub _get_pod_usage {
+<<<<<<< HEAD
 	return if $SYNOPSIS;
 	our $level;
 	open SCR_POD, $0 or warn "failed to open $0 for reading; $!";
@@ -349,6 +350,60 @@ sub _get_pod_usage {
 		$PROGNAME ||= $1;
 		$SHORT_DESC ||= $2;
 	}
+=======
+    return if $SYNOPSIS;
+    (undef, my ($fn, $line)) = sub{caller()}->();
+    eval "# line $line \"$fn\"\npackage main;\n".q{
+        our $level;
+        use Pod::Constants;
+        Pod::Constants::import_from_file($0, -trim => 1,
+            'NAME' => sub {
+	my @m;
+	( @m = m/(\S+) - (.*)/ ) &&
+	    do { $Scriptalicious::PROGNAME = $m[0];
+		 $Scriptalicious::SHORT_DESC = $m[1]; }
+	},
+            'SYNOPSIS' => \$Scriptalicious::SYNOPSIS,
+            'DESCRIPTION' => \$Scriptalicious::DESCRIPTION,
+            'COMMAND LINE OPTIONS' => sub {
+	        &Pod::Constants::add_hook
+		   ('*item' => sub {
+                     return unless $level == 1;
+		     my ($switches, $description) =
+			 m/^(.*?)\n\n(.*)/s;
+                     $switches =~ s{[BCI]<([^>]*)>}{$1}g;
+		     my (@switches, $longest);
+		     $longest = "";
+		     for my $switch
+			 ($switches =~ m/\G
+					 ((?:-\w|--\w[-\w]*))
+					 (?:,\s*)?
+					 /gx) {
+			     push @switches, $switch;
+			     if ( length $switch > length $longest) {
+				 $longest = $switch;
+			     }
+			 }
+		     $longest =~ s/^-*//;
+		     push @options,
+			 $longest, {
+				    options => \@switches,
+				    description => $description,
+				   };
+                     });
+                &Pod::Constants::add_hook
+                   ("*over" => sub { $level++ });
+                &Pod::Constants::add_hook
+                   ("*back" => sub {
+                       --$level or do {
+                           &Pod::Constants::delete_hook($_)
+                               foreach qw(*over *back *item);
+                       };
+                    });
+            }
+        );
+    };
+>>>>>>> 20d0d38f5fa1386b4fb1b1986fa2349f7c9d6b10
 
 	foreach ( $SYNOPSIS, $SHORT_DESC, $DESCRIPTION ) {
 	    $_ ||= "(not found in POD)";
